"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v0.0.1-alpha.3
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import unittest

import ory_client
from ory_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_identity_admin(self):
        """Test case for create_identity_admin

        Create an Identity  # noqa: E501
        """
        pass

    def test_create_recovery_link_admin(self):
        """Test case for create_recovery_link_admin

        Create a Recovery Link  # noqa: E501
        """
        pass

    def test_delete_identity_admin(self):
        """Test case for delete_identity_admin

        Delete an Identity  # noqa: E501
        """
        pass

    def test_get_identity_admin(self):
        """Test case for get_identity_admin

        Get an Identity  # noqa: E501
        """
        pass

    def test_get_schema(self):
        """Test case for get_schema

        """
        pass

    def test_get_schema_admin(self):
        """Test case for get_schema_admin

        """
        pass

    def test_get_self_service_error(self):
        """Test case for get_self_service_error

        Get User-Facing Self-Service Errors  # noqa: E501
        """
        pass

    def test_get_self_service_error_admin(self):
        """Test case for get_self_service_error_admin

        Get User-Facing Self-Service Errors  # noqa: E501
        """
        pass

    def test_get_self_service_login_flow(self):
        """Test case for get_self_service_login_flow

        Get Login Flow  # noqa: E501
        """
        pass

    def test_get_self_service_login_flow_admin(self):
        """Test case for get_self_service_login_flow_admin

        Get Login Flow  # noqa: E501
        """
        pass

    def test_get_self_service_recovery_flow(self):
        """Test case for get_self_service_recovery_flow

        Get information about a recovery flow  # noqa: E501
        """
        pass

    def test_get_self_service_recovery_flow_admin(self):
        """Test case for get_self_service_recovery_flow_admin

        Get information about a recovery flow  # noqa: E501
        """
        pass

    def test_get_self_service_registration_flow(self):
        """Test case for get_self_service_registration_flow

        Get Registration Flow  # noqa: E501
        """
        pass

    def test_get_self_service_registration_flow_admin(self):
        """Test case for get_self_service_registration_flow_admin

        Get Registration Flow  # noqa: E501
        """
        pass

    def test_get_self_service_settings_flow(self):
        """Test case for get_self_service_settings_flow

        Get Settings Flow  # noqa: E501
        """
        pass

    def test_get_self_service_settings_flow_admin(self):
        """Test case for get_self_service_settings_flow_admin

        Get Settings Flow  # noqa: E501
        """
        pass

    def test_get_self_service_verification_flow(self):
        """Test case for get_self_service_verification_flow

        Get Verification Flow  # noqa: E501
        """
        pass

    def test_get_self_service_verification_flow_admin(self):
        """Test case for get_self_service_verification_flow_admin

        Get Verification Flow  # noqa: E501
        """
        pass

    def test_get_version_admin(self):
        """Test case for get_version_admin

        Return Running Software Version.  # noqa: E501
        """
        pass

    def test_initialize_self_service_browser_logout_flow(self):
        """Test case for initialize_self_service_browser_logout_flow

        Initialize Browser-Based Logout User Flow  # noqa: E501
        """
        pass

    def test_initialize_self_service_login_for_browsers(self):
        """Test case for initialize_self_service_login_for_browsers

        Initialize Login Flow for browsers  # noqa: E501
        """
        pass

    def test_initialize_self_service_login_for_native_apps(self):
        """Test case for initialize_self_service_login_for_native_apps

        Initialize Login Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_recovery_for_browsers(self):
        """Test case for initialize_self_service_recovery_for_browsers

        Initialize Recovery Flow for Browser Clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_recovery_for_native_apps(self):
        """Test case for initialize_self_service_recovery_for_native_apps

        Initialize Recovery Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_registration_for_browsers(self):
        """Test case for initialize_self_service_registration_for_browsers

        Initialize Registration Flow for browsers  # noqa: E501
        """
        pass

    def test_initialize_self_service_registration_for_native_apps(self):
        """Test case for initialize_self_service_registration_for_native_apps

        Initialize Registration Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_settings_for_browsers(self):
        """Test case for initialize_self_service_settings_for_browsers

        Initialize Settings Flow for Browsers  # noqa: E501
        """
        pass

    def test_initialize_self_service_settings_for_native_apps(self):
        """Test case for initialize_self_service_settings_for_native_apps

        Initialize Settings Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_verification_for_browsers(self):
        """Test case for initialize_self_service_verification_for_browsers

        Initialize Verification Flow for Browser Clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_verification_for_native_apps(self):
        """Test case for initialize_self_service_verification_for_native_apps

        Initialize Verification Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_is_alive_admin(self):
        """Test case for is_alive_admin

        Check HTTP Server Status  # noqa: E501
        """
        pass

    def test_is_ready_admin(self):
        """Test case for is_ready_admin

        Check HTTP Server and Database Status  # noqa: E501
        """
        pass

    def test_list_identities_admin(self):
        """Test case for list_identities_admin

        List Identities  # noqa: E501
        """
        pass

    def test_prometheus_admin(self):
        """Test case for prometheus_admin

        Get snapshot metrics from the Hydra service. If you're using k8s, you can then add annotations to your deployment like so:  # noqa: E501
        """
        pass

    def test_revoke_session(self):
        """Test case for revoke_session

        Initialize Logout Flow for API Clients - Revoke a Session  # noqa: E501
        """
        pass

    def test_submit_self_service_login_flow(self):
        """Test case for submit_self_service_login_flow

        Submit a Login Flow  # noqa: E501
        """
        pass

    def test_submit_self_service_recovery_flow(self):
        """Test case for submit_self_service_recovery_flow

        Complete Recovery Flow  # noqa: E501
        """
        pass

    def test_submit_self_service_recovery_flow_with_link_method(self):
        """Test case for submit_self_service_recovery_flow_with_link_method

        Complete Recovery Flow with Link Method  # noqa: E501
        """
        pass

    def test_submit_self_service_registration_flow(self):
        """Test case for submit_self_service_registration_flow

        Submit a Registration Flow  # noqa: E501
        """
        pass

    def test_submit_self_service_settings_flow(self):
        """Test case for submit_self_service_settings_flow

        Complete Settings Flow  # noqa: E501
        """
        pass

    def test_submit_self_service_verification_flow(self):
        """Test case for submit_self_service_verification_flow

        Complete Verification Flow  # noqa: E501
        """
        pass

    def test_to_session(self):
        """Test case for to_session

        Check Who the Current HTTP Session Belongs To  # noqa: E501
        """
        pass

    def test_update_identity_admin(self):
        """Test case for update_identity_admin

        Update an Identity  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
